pub struct EdgeAttr {Show 31 fields
pub length_m: f64,
pub ascent_m: f64,
pub descent_m: f64,
pub grade_abs_mean: f64,
pub grade_abs_max: f64,
pub sustained_steep_m: f64,
pub grade_distribution: GradeDistribution,
pub hill_slope_deg: Option<f64>,
pub way_kind: WayKind,
pub realm: WayRealm,
pub geometry_claim: GeometryClaim,
pub crossing_control: CrossingControl,
pub standing: TrailStanding,
pub marking: TrailMarking,
pub terrain: Terrain,
pub surface: Option<String>,
pub terrain_confidence: f64,
pub terrain_evidence: Vec<TerrainEvidence>,
pub access: Access,
pub travel: EdgeTravel,
pub access_confidence: f64,
pub access_provenance: Vec<Provenance>,
pub crossings: Vec<CrossingEvidence>,
pub road_exposure: f64,
pub confidence: f64,
pub traversal: EdgeTraversal,
pub seed_count: u32,
pub popularity: f64,
pub seed_provenance: Vec<Provenance>,
pub elevation_provenance: Vec<Provenance>,
pub provenance: Vec<Provenance>,
}Fields
length_m: f64ascent_m: f64descent_m: f64grade_abs_mean: f64grade_abs_max: f64sustained_steep_m: f64grade_distribution: GradeDistributionhill_slope_deg: Option<f64>Mean magnitude of the surrounding terrain slope in degrees. This is distinct from grade along the trail and may be absent without a DEM.
way_kind: WayKindrealm: WayRealmgeometry_claim: GeometryClaimcrossing_control: CrossingControlstanding: TrailStandingmarking: TrailMarkingterrain: Terrainsurface: Option<String>terrain_confidence: f64terrain_evidence: Vec<TerrainEvidence>access: Accesstravel: EdgeTravelaccess_confidence: f64access_provenance: Vec<Provenance>crossings: Vec<CrossingEvidence>road_exposure: f64confidence: f64traversal: EdgeTraversalseed_count: u32popularity: f64seed_provenance: Vec<Provenance>elevation_provenance: Vec<Provenance>provenance: Vec<Provenance>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for EdgeAttr
impl<'de> Deserialize<'de> for EdgeAttr
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for EdgeAttr